@@ -1,5 +1,4 @@
 import socket
-import os
 import gymnasium as gym
 import math
 import numpy as np
@@ -10,11 +9,10 @@ from FlagCapture.miniworld import MiniWorldEnv
 from FlagCapture.utils import get_file_path
 from  FlagCapture.build import BUILD
 from threading import Thread as T
-import sys
 
 BUILD()
 
-Ip = '73.103.247.204'
+Ip = socket.gethostbyname('Anthony')
 Port = 4544
 
 ADDR = (Ip, Port)
@@ -24,7 +22,7 @@ cl.connect(ADDR)
 
 cl.send('Capture the red-and-blue special flags that are available for capture.'.encode('utf-8'))
 
-start_info = eval(cl.recv(58000).decode('utf-8'))
+start_info = eval(cl.recv(58000).decode('utf-8').split('A@^!')[0])
 
 class Scene(MiniWorldEnv):
     def __init__(self, **kwargs):
@@ -109,10 +107,8 @@ class Scene(MiniWorldEnv):
         self.add_rect_room(min_x=82, max_x=82.01, max_z=-49, min_z=-58, wall_tex='blueColor')
         self.redGate = self.place_entity(MeshEnt(mesh_name=f'gate', height=2.6), pos=[48, 0, 49], dir=-3.1)
         self.blueGate = self.place_entity(MeshEnt(mesh_name=f'gate', height=2.6), pos=[48, 0, -49], dir=6.3)
-        self.leftRedButton = self.place_entity(MeshEnt(mesh_name=f'RedButton', height=1), pos=[82.5, 1, -44.749], dir=-1.5)
-        self.rightRedButton = self.place_entity(MeshEnt(mesh_name=f'RedButton', height=1), pos=[9.5, 1, -44.749], dir=-1.5)
-        self.rightBlueButton = self.place_entity(MeshEnt(mesh_name=f'BlueButton', height=1), pos=[9.5, 1, 44.749], dir=1.6)
-        self.leftBlueButton = self.place_entity(MeshEnt(mesh_name=f'BlueButton', height=1), pos=[82.5, 1, 44.749], dir=1.6)
+        self.redFlag = self.place_entity(MeshEnt(mesh_name=f'flagRed', height=2.5, static=False), pos=start_info['RedFlagPos'])
+        self.blueFlag = self.place_entity(MeshEnt(mesh_name=f'flagBlue', height=2.5, static=False), pos=start_info['BlueFlagPos'])
         for person in start_info['Everything']:
             animal = self.place_entity(MeshEnt(mesh_name=f''+start_info['Everything'][person]['team'], height=1.4, static=False), pos=start_info['Everything'][person]['pos'], dir=start_info['Everything'][person]['dir'])
             people[person] = animal
@@ -120,8 +116,10 @@ class Scene(MiniWorldEnv):
                 list_of_players_on_my_team.append(person)
             else:
                 list_of_players_on_their_team.append(person)
-        self.redFlag = self.place_entity(MeshEnt(mesh_name=f'flagRed', height=2.5, static=False), pos=start_info['RedFlagPos'])
-        self.blueFlag = self.place_entity(MeshEnt(mesh_name=f'flagBlue', height=2.5, static=False), pos=start_info['BlueFlagPos'])
+        self.leftRedButton = self.place_entity(MeshEnt(mesh_name=f'RedButton', height=1), pos=[82.5, 1, -44.749], dir=-1.5)
+        self.rightRedButton = self.place_entity(MeshEnt(mesh_name=f'RedButton', height=1), pos=[9.5, 1, -44.749], dir=-1.5)
+        self.rightBlueButton = self.place_entity(MeshEnt(mesh_name=f'BlueButton', height=1), pos=[9.5, 1, 44.749], dir=1.6)
+        self.leftBlueButton = self.place_entity(MeshEnt(mesh_name=f'BlueButton', height=1), pos=[82.5, 1, 44.749], dir=1.6)
         self.place_agent()
 
 gym.envs.registration.register(id='Enviroment', entry_point=Scene)
@@ -135,6 +133,8 @@ list_of_players_on_my_team = []
 list_of_players_on_their_team = []
 people = {}
 
+creating = False
+
 board = key.KeyStateHandler()
 scene = gym.make("Enviroment", view='agent', render_mode='human')
 scene.unwrapped.fuel = 5
@@ -240,8 +240,6 @@ def red_wins():
     pyglet.clock.schedule_once(close, 4)
     alert(get_file_path("images", "lynxwin", "png"), 4)
 
-creating = False
-
 def drop_flag():
     global carrying
     if carrying:
@@ -274,7 +272,7 @@ def on_draw():
 def recv():
     global raw_message
     while True:
-        raw_message = cl.recv(58000).decode('utf-8')
+        raw_message = cl.recv(58000).decode('utf-8').split('A@^!')[0]
         if raw_message.strip() == '':continue
         pyglet.clock.schedule_once(process_message, 1.0/60)
 
