@@ -944,7 +944,7 @@ class MiniWorldEnv(gym.Env):
             return True
 
         # Check for entity intersection
-        for ent2 in self.entities:
+        for ent2 in self.entities[::-1]:
             # Entities can't intersect with themselves
             if ent2 is ent:
                 continue
